## File "Configs/actions.py"
## -*- coding: utf-8 -*-
# 
# Configuration of actions.



## DELETED_ACTIONS
# 
# List in this dictionary the actions to be deleted
# 
# 
# * 'id' (required) : string
#   id of the action to be deleted
# 
# * 'category' (required) : string
#   category of the action to be deleted
# 
# 
DELETED_ACTIONS = {
  'portal_actions' : (
                        {
                          'id' : 'ArcDeSeine_home',
                          'category' : 'portal_tabs',
                        },
                      ),
}



##---------------------------------------------------------------------------



## CREATED_ACTIONS
#
# * 'id' (required) : string
#   Id
# 
# * 'category' (required) : string
#   Category
# 
# * 'name' (required) : string
#   Title / Name
# 
# * 'action' (required) : tal expression
#   URL of the action.
# 
# * 'condition' (required) : tal expression
#   Tal expression to be matched for the action to be visible.
# 
# * 'permissions' (required) : tuple
#   Permission to be matched for the action to be visible.
# 
# * 'visible' (optional - default : True) : boolean
#   Determine wether the action is visible or not.
# 
# 
# See addAction() arguments in CMFCore/ActionProviderBase.py
# for the latest list of all available keys and default values.
# 
# 
CREATED_ACTIONS = {
  'portal_actions' : (
    {'id' : 'ArcDeSeine_home', 'name' : 'Home', 'action' : 'string:$portal_url', 'category' : 'portal_tabs', 'permission' : 'View', 'visible' : 1, 'REQUEST' : None, 'condition' : ''},
    {'id' : 'ArcDeSeine_siteMap', 'name' : 'Site Map', 'action' : 'string:$portal_url/sitemap', 'category' : 'portal_tabs', 'permission' : 'View', 'visible' : True, 'REQUEST' : None, 'condition' : ''},
    {'id' : 'ArcDeSeine_newsletter', 'name' : 'Newsletter', 'action' : 'string:$portal_url/newsletter', 'category' : 'portal_tabs', 'permission' : 'View', 'visible' : True, 'REQUEST' : None, 'condition' : ''},
    {'id' : 'ArcDeSeine_photoAlbum', 'name' : 'Photo album', 'action' : 'string:$portal_url/album_photo', 'category' : 'portal_tabs', 'permission' : 'View', 'visible' : True, 'REQUEST' : None, 'condition' : ''},
    {'id' : 'ArcDeSeine_interactiveMap', 'name' : 'Interactive Map', 'action' : 'string:$portal_url/plan-interactif', 'category' : 'portal_tabs', 'permission' : 'View', 'visible' : True, 'REQUEST' : None, 'condition' : ''},

    {'id' : 'ArcDeSeine_onlineRequests', 'name' : 'Online requests', 'action' : 'string:$portal_url/demarches_en_ligne', 'category' : 'arcdeseine_tabs', 'permission' : 'View', 'visible' : True, 'REQUEST' : None, 'condition' : ''},
    {'id' : 'ArcDeSeine_recruting', 'name' : 'Recruting', 'action' : 'string:$portal_url/recrutement', 'category' : 'arcdeseine_tabs', 'permission' : 'View', 'visible' : True, 'REQUEST' : None, 'condition' : ''},
  ),
}



##---------------------------------------------------------------------------



## UPDATED_ACTIONS
# 
# Dictionary of updated actions.
# 
# * 'id' (required) : string
#   Id of the updated action
# 
# * 'category' (required) : string
#   Category of the updated action.
# 
# * 'new_id' (optional - default : _unchanged) : string
#   new id of the updated action
# 
# * 'new_category' (optional - default : _unchanged) : string
#   new category of the updated action.
# 
# * 'title' (optional - default : _unchanged) : string
#   Title / Name
# 
# * 'condition' (optional - default : _unchanged) : tal expression
#   Tal expression to be matched for the action to be visible.
# 
# * 'permissions' (optional - default : _unchanged) : tuple
#   Permission to be matched for the action to be visible.
# 
# * 'visible' (optional - default : _unchanged) : boolean
#   Determine wether the action is visible or not.
# 
# * 'action' (optional - default : _unchanged) : tal expression
#   URL of the action.
# 
# 
# See ActionInformation.edit() arguments in CMFCore/ActionInformation.py
# for the latest list of all available keys and default values.
# 
# 
UPDATED_ACTIONS = {
  'portal_actions' : (
    { 
      'id' : 'index_html',
      'category' : 'portal_tabs',
      'visible' : False,
    },
    { 
      'id' : 'sitemap',
      'category' : 'portal_tabs',
      'visible' : False,
    },
    {
      'id' : 'folderContents',
      'category' : 'object',
      'condition' : 'python: object.displayContentsTab and ((object.isDefaultPageInFolder() and portal.portal_membership.checkPermission(\'Modify portal content\', object.getParentNode())) or (portal.portal_membership.checkPermission(\'Modify portal content\', object) and not object.isDefaultPageInFolder()))',
    },
    { 'id' : 'full_screen', 'category' : 'document_actions', 'visible' : False, },
    { 'id' : 'extedit', 'category' : 'document_actions', 'visible' : False, },
  ),
  'portal_membership' : (
    { 'id' : 'mystuff', 'category' : 'user', 'visible' : False, },
  ),
  'portal_undo' : (
    { 'id' : 'undo', 'category' : 'user', 'visible' : False, },
  ),
  'portal_controlpanel' : (
    { 'id' : 'UsersGroups', 'category' : 'Plone', 'new_category' : 'Member', },
  ),
  'portal_types/Image' : (
    { 'id' : 'transform', 'category' : 'object', 'visible' : False, },
    { 'id' : 'metadata', 'category' : 'object', 'visible' : False, },
  ),
  'portal_types/File' : (
    { 'id' : 'metadata', 'category' : 'object', 'visible' : False, },
  ),
  'portal_types/Folder' : (
    {
      'id' : 'edit',
      'category' : 'object',
      'condition' : 'python: (not portal.portal_workflow.getInfoFor(object, \'review_state\') == \'published\') or list(portal.portal_membership.getAuthenticatedMember().getRolesInContext(object)).count(\'Manager\') > 0'
    },
    {
      'id' : 'metadata',
      'category' : 'object',
      'condition' : 'python: (not portal.portal_workflow.getInfoFor(object, \'review_state\') == \'published\') or list(portal.portal_membership.getAuthenticatedMember().getRolesInContext(object)).count(\'Manager\') > 0'
    },
  ),
  'portal_types/NewsletterTheme' : (
    { 'id' : 'subscribe', 'category' : 'object', 'visible' : False, },
  ),
}



