## File "PloneInstaller/Scripts/skins_setup.py"
## -*- coding: utf-8 -*-
# 
# This file use the configuration described in "Configs/skins.py" to setup the product skins.



import traceback, os
from os.path import isdir, join
from types import *

from Globals import package_home
from Products.Archetypes.Extensions.utils import install_subskin
from Products.CMFCore.utils import getToolByName, minimalpath
from Products.CMFCore.DirectoryView import addDirectoryViews, \
     registerDirectory, manage_listAvailableDirectories
from OFS.ObjectManager import BadRequestException



#########################################################################################################
########################################## Public methods ###############################################
#########################################################################################################



def skins_install(self, out, project_name, globals):
    try:
      skin_definitions_module = __import__("Configs.skins",
                                            globals, locals(),
                                           [
                                              'FILE_EXTENSIONS',
                                              'SKIN_DEFINITIONS',
                                              'STYLESHEETS',
                                              'JAVASCRIPTS',
                                            ]
                                          )

      out.openSection("Configs.skins setup")

      # Skins definitions.
      skin_definitions = getattr(skin_definitions_module, 'SKIN_DEFINITIONS', None)
      if skin_definitions != None:
        _installSkins(self, out, skin_definitions, globals)

      # Stylesheets registration
      stylesheets = getattr(skin_definitions_module, 'STYLESHEETS', None)
      if stylesheets != None:
        _installStylesheets(self, out, stylesheets)

      # Scripts registration
      javascripts = getattr(skin_definitions_module, 'JAVASCRIPTS', None)
      if javascripts != None:
        _installJavascripts(self, out, javascripts)

      out.closeSection("Configs.skins setup")

    except ImportError:
      out.info("Config.skins setup : Nothing to be done.")



##---------------------------------------------------------------------------



def skins_remove(self, out, project_name, globals):
    try:
      skin_definitions_module = __import__("Configs.skins",
                                            globals, locals(),
                                           [
                                              'FILE_EXTENSIONS',
                                              'SKIN_DEFINITIONS',
                                              'STYLESHEETS',
                                              'JAVASCRIPTS',
                                            ]
                                          )

      out.openSection("Configs.skins removal")

      # Skins definitions.
      skin_definitions = getattr(skin_definitions_module, 'SKIN_DEFINITIONS', None)
      if skin_definitions != None:
        _removeSkins(self, out, skin_definitions)

      # Stylesheets registration
      stylesheets = getattr(skin_definitions_module, 'STYLESHEETS', None)
      if stylesheets != None:
        _removeStylesheets(self, out, stylesheets)

      # Scripts registration
      javascripts = getattr(skin_definitions_module, 'JAVASCRIPTS', None)
      if javascripts != None:
        _removeJavascripts(self, out, javascripts)

      out.closeSection("Configs.skins removal")

    except ImportError:
      out.info("Configs.skins removal : Nothing to be done.")



#########################################################################################################
######################################## Install functions ##############################################
#########################################################################################################



## _installSkins
# 
# Register this product skins directories into plone existing skins
# or create a skin associated with this product.
def _installSkins(self, out, skin_definitions, globals):
    errorFlag = False

    out.openSubsection("Skins setup")

    for skin_definition in skin_definitions:  # For each skin directory declared into configuration

        if skin_definition.has_key('skin_name'): # Check the type of skin directory contents.

            try: # Create the skin associated to the computed directory.
                _install_skin(self, out, globals, skin_definition['skin_dir'], skin_definition['skin_name'], skin_definition.get('base_skin', None))
                out.log("Installed skin named '%s' from directory '%s'." % (skin_definition['skin_name'], skin_definition['skin_dir']))
            except Exception, e:
                errorFlag = true
                out.error("can not install skin named '%s' from directory '%s'. (Error message : %s)" %  (skin_definition['skin_name'], skin_definition['skin_dir'], str(e)) )
            else:

                if skin_definition.get('select_skin', False):

                    try: # Check portal_skins existance
                        skins_tool = getToolByName(self, 'portal_skins')
                    except AttributeError:
                        errorFlag = true
                        out.error("'portal_skins' tool not found !")
                    else:

                        try: # Setting create skin as default portal skin
                            skins_tool.manage_properties(default_skin = skin_definition['skin_name'])
                            out.log("Setted up skin '%s' as default skin." % skin_definition['skin_name'])
                        except Exception, e:
                            errorFlag = true
                            out.error("can not set skin '%s' as default skin. (Error message : %s)" % (skin_definition['skin_name'], str(e)) )

        else: # Check the type of skin directory contents.

          try: # Register directory contents to all existing skins
            install_subskin(self, out, globals, skin_definition['skin_dir'])
            out.log("Installed files from directory '%s' into all skins." % skin_definition['skin_dir'])
          except Exception, e:
            errorFlag = True
            out.error("can not install files from directory '%s' into all skins. (Error message : %s)" % (skin_definition['skin_dir'], str(e)) )

    if not errorFlag:
        out.success("Completed skin setup without errors.")

    out.closeSubsection("Skins setup")



##---------------------------------------------------------------------------



## _installStylesheets
# 
# Register this product's stylesheets into Plone CSS tool.
def _installStylesheets(self, out, stylesheets):
    errorFlag = False

    out.openSubsection("Stylesheets setup")

    try: # Check for CSS tool existance
        csstool = getToolByName(self, 'portal_css')
    except AttributeError:
        errorFlag = True
        out.error("'portal_css' tool not found !")

    else:
      for stylesheet in stylesheets: # For each configured stylesheet.
          try: # We register the stylesheet
              csstool.registerStylesheet(**stylesheet)
              out.log("Registered stylesheet '%s'." % stylesheet['id'])
          except Exception, e:
              errorFlag = True
              out.error("can not register stylesheet '%s'. (Error message : %s)" % (stylesheet['id'], str(e)) )


      if not errorFlag:
          out.success("Completed stylesheets setup without errors.")

    out.closeSubsection("Stylesheets setup")



##---------------------------------------------------------------------------



## _installJavascripts
# 
# Register this product's javascripts into Plone Javascripts tool.
def _installJavascripts(self, out, javascripts):
    errorFlag = False

    out.openSubsection("Javascripts setup")

    try: # Check for Javascripts tool existance
        jstool = getToolByName(self, 'portal_javascripts')
    except AttributeError:
        errorFlag = True
        out.error("'portal_javascripts' tool not found !")

    else:
      for javascript in javascripts: # For each configured javascript
          try: # We register the javascript
              jstool.registerScript(**javascript)
              out.log("Registered stylesheet '%s'." % javascript['id'])
          except Exception, e:
              errorFlag = True
              out.error("can not register javascript '%s'. (Error message : %s)" % (javascript['id'], str(e)) )

      if not errorFlag:
          out.success("Completed javascripts setup without errors.")

    out.closeSubsection("Javascripts setup")



#########################################################################################################
######################################### Remove functions ##############################################
#########################################################################################################



## _removeSkins
# 
# Delete skins created by this product.
def _removeSkins(self, out, skin_definitions):
    errorFlag = False

    out.openSubsection("Skins removal")

    try: # Check portal_skins existance
        skins_tool = getToolByName(self, 'portal_skins')
    except AttributeError:
        errorFlag = true
        out.error("'portal_skins' tool not found !")
    else:
        for skin_definition in skin_definitions: # For each configured directory
            if skin_definition.get('skin_name', None) in skins_tool.getSkinSelections(): # If the directory contain a skin
                # Unregister product skin from portal_skins
                try:
                    skins_tool.manage_skinLayers(del_skin=1, chosen=(skin_definition['skin_name'],))
                    out.log("Removed skin '%s' from 'portal_skins'." % skin_definition['skin_name'])
                except Exception, e:
                    errorFlag = True
                    out.error("can not remove skin '%s' from 'portal_skins'. (Error message : %s)" % (skin_definition['skin_name'], str(e)) )

                if skin_definition.get('select_skin', False) and skin_definition.get('base_skin', None): # Set up the default skin if necessary
                    try:
                        skins_tool.manage_properties(default_skin = skin_definition.get('base_skin', ''))
                        out.log("Setted up skin '%s' as default skin." % skin_definition.get('base_skin', ''))
                    except Exception, e:
                        errorFlag = True
                        out.error("Can not setup '%s' as default skin. (Error message : %s)" % (skin_definition.get('base_skin', ''), str(e)) )

        if not errorFlag:
            out.success("Completed skins removal without errors.")

    out.closeSubsection("Skins removal")



##---------------------------------------------------------------------------



## _removeStylesheets
# 
# Remove stylesheets registered by this product.
def _removeStylesheets(self, out, stylesheets):
    errorFlag = False

    out.openSubsection("Stylesheets removal")

    try: # Check for CSS tool existance
        csstool = getToolByName(self, 'portal_css')
    except AttributeError:
        errorFlag = True
        out.error("'portal_css' tool not found !")
    else:

        for stylesheet in stylesheets: # For each stylesheet.
            try:
                csstool.unregisterResource(stylesheet.get('id', ''))
                out.log("Removed stylesheet '%s' from 'portal_css'." % stylesheet.get('id', ''))
            except Exception, e:
                errorFlag = True
                out.error("can not remove stylesheet '%s' from 'portal_css'. (Error message : %s)" % (stylesheet.get('id', ''), str(e)) )

        if not errorFlag:
            out.success("Completed stylesheets removal without errors.")

    out.closeSubsection("Stylesheets removal")



##---------------------------------------------------------------------------



## _removeJavascripts
# 
# Remove javascripts registered by this product.
def _removeJavascripts(self, out, javascripts):
    errorFlag = False

    out.openSubsection("Javascripts removal")

    try: # Check for Javascripts tool existance
        jstool = getToolByName(self, 'portal_javascripts')
    except AttributeError:
        errorFlag = True
        out.error("'portal_javascripts' tool not found !")
    else:

        for javascript in javascripts: # For each javascript.
            try:
                jstool.unregisterResource(javascript.get('id', ''))
                out.log("Removed javascript '%s' from 'portal_javascripts'." % javascript.get('id', ''))
            except Exception, e:
                errorFlag = True
                out.error("can not remove javascript '%s' from 'portal_javascripts'. (Error message : %s)" % (javascript.get('id', ''), str(e)) )

        if not errorFlag:
            out.success("Completed javascripts removal without errors.")

    out.closeSubsection("Javascripts removal")



#########################################################################################################
######################################### Private functions #############################################
#########################################################################################################



## _install_skin
# 
# Based on Archetype install_subskin
# Create a new skin and register directory contents into it.
def _install_skin(self, out, globals, skins_dir, skin_name, skin_base_skin = None):
    skinstool=getToolByName(self, 'portal_skins')

    fullProductSkinsPath = os.path.join(package_home(globals), skins_dir)
    productSkinsPath = minimalpath(fullProductSkinsPath)
    registered_directories = manage_listAvailableDirectories()
    if productSkinsPath not in registered_directories:
        try:
            registerDirectory(skins_dir, globals)
        except OSError, ex:
            if ex.errno == 2: # No such file or directory
                return
            raise
    try:
        addDirectoryViews(skinstool, skins_dir, globals)
    except BadRequestException, e:
        # XXX: find a better way to do this, but that seems not feasible
        #      until Zope stops using string exceptions
        if str(e).endswith(' is reserved.'):
            # trying to use a reserved identifier, let the user know
            #
            # remember the cmf reserve ids of objects in the root of the
            # portal !
            raise
        # directory view has already been added
        pass

    # Create the skin if it does not exists.
    if skin_name not in skinstool.getSkinSelections():
        layers = ""
        # Get the skin layers of the base skin and convert to an array
        if skin_base_skin:
          layers = skinstool.getSkinPath(skin_base_skin)

        # Add our skin selection
        skinstool.addSkinSelection(skin_name, layers)

    # Add the files to the newly created skin.
    files = os.listdir(fullProductSkinsPath)
    for productSkinName in files:
        # skip directories with a dot or special dirs
        # or maybe just startswith('.')?
        if productSkinName.find('.') != -1 or productSkinName in ('CVS', '{arch}'):
            continue
        if isdir(join(fullProductSkinsPath, productSkinName)):
            path = skinstool.getSkinPath(skin_name)
            path = [i.strip() for i in  path.split(',')]
            try:
                if productSkinName not in path:
                    path.insert(path.index('custom') +1, productSkinName)
            except ValueError:
                if productSkinName not in path:
                    path.append(productSkinName)
            path = ','.join(path)
            skinstool.addSkinSelection(skin_name, path)

